==> 1.02.tar.gz: amiga-ntimed/compiler.h <==
/*
 * Copyright (c) 2015 Carsten Larsen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifndef NTIMED_COMPILER_H
#define NTIMED_COMPILER_H

#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <errno.h>
#include <signal.h>
#include <math.h>

/*
 * See also:
 * http://codewiz.org/projects/amiga/Headers/CompilerSpecific.h
 *
 */

#ifdef __VBCC__
# include <stdint.h>
# include <sys/socket.h>
# define nan(p) NAN
# define __inline
# define  __printflike(a, b)
# define round(x) x > 0.0 ? floor(x + 0.5) : ceil(x - 0.5)
typedef uint32_t register_t;
#endif

#ifdef __GNUC__
# if (__GNUC__ == 2 && __GNUC_MINOR__ == 95)
#  include <math.h>
#  include <sys/types.h>
#  define round(x) x > 0.0 ? floor(x + 0.5) : ceil(x - 0.5)
#  define nan(p) 0./0.
typedef u_int8_t    uint8_t;
typedef u_int16_t   uint16_t;
typedef u_int32_t   uint32_t;
typedef u_int64_t   uint64_t;
typedef uint32_t            uintptr_t;
typedef unsigned int        socklen_t;
# endif

# ifdef AROS
#  include <stdint.h>
typedef uint32_t            register_t;
# endif
#endif

#ifdef __GNUC__
# define HAVE_ASCTIME
typedef uint16_t            in_port_t;
typedef unsigned int        sa_family_t;
#endif

// General socket address holding structure, big enough to hold either
// struct sockaddr_in or struct sockaddr_in6 data:
struct sockaddr_storage {
    sa_family_t  ss_family;     // address family

    // all this is padding, implementation specific, ignore it:
    char      __ss_pad1[128 - sizeof(sa_family_t)];
};

#endif

==> 1.05.tar.gz: amiga-ntimed/compiler.h <==
//--------------------------------------------------------------------------//
/* Copyright (c) 2015 Carsten Larsen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
//--------------------------------------------------------------------------//
#ifndef NTIMED_COMPILER_H
#define NTIMED_COMPILER_H
//--------------------------------------------------------------------------//
#include <stdlib.h>
#include <string.h>
#include <stdio.h>
#include <errno.h>
#include <signal.h>
#include <math.h>
//--------------------------------------------------------------------------//
// More info at:
// http://codewiz.org/projects/amiga/Headers/CompilerSpecific.h
//--------------------------------------------------------------------------//
#ifdef __VBCC__
# include <stdint.h>
# include <sys/socket.h>
# define nan(p) NAN
# define __inline
# define  __printflike(a, b)
# define round(x) x > 0.0 ? floor(x + 0.5) : ceil(x - 0.5)
typedef uint32_t register_t;
#endif
//--------------------------------------------------------------------------//
#ifdef __GNUC__
# if (__GNUC__ == 2 && __GNUC_MINOR__ == 95)
#  include <math.h>
#  include <sys/types.h>
#  define round(x) x > 0.0 ? floor(x + 0.5) : ceil(x - 0.5)
#  define nan(p) 0./0.
typedef u_int8_t     uint8_t;
typedef u_int16_t    uint16_t;
typedef u_int32_t    uint32_t;
typedef u_int64_t    uint64_t;
typedef uint32_t     uintptr_t;
typedef unsigned int socklen_t;
# endif
# ifdef AROS
#  include <stdint.h>
typedef uint32_t     register_t;
# endif
typedef uint16_t     in_port_t;
typedef unsigned int sa_family_t;
#endif
//--------------------------------------------------------------------------//
struct sockaddr_storage {
    sa_family_t   ss_family;
    char        __ss_pad1[128 - sizeof(sa_family_t)];
};
//--------------------------------------------------------------------------//
#endif
